pub struct ContiguousArena<Idx, T> { /* private fields */ }Expand description
This is a Vec behind a generational arena.
The goal of this structure is to have unique identifiers for elements
stored contiguously on a Vec.
Implementations
Sourceimpl<Idx, T> ContiguousArena<Idx, T>
impl<Idx, T> ContiguousArena<Idx, T>
Sourcepub fn get_from_contiguous_index(&self, index: usize) -> Option<(&T, Idx)>where
Idx: From<ContiguousArenaIndex>,
pub fn get_from_contiguous_index(&self, index: usize) -> Option<(&T, Idx)>where
Idx: From<ContiguousArenaIndex>,
Get an element from its position on the contiguous array.
Sourcepub fn get(&self, handle: Idx) -> Option<&T>where
Idx: Into<ContiguousArenaIndex>,
pub fn get(&self, handle: Idx) -> Option<&T>where
Idx: Into<ContiguousArenaIndex>,
Gets a reference to the object identified by handle.
Sourcepub fn get_mut(&mut self, handle: Idx) -> Option<&mut T>where
Idx: Into<ContiguousArenaIndex>,
pub fn get_mut(&mut self, handle: Idx) -> Option<&mut T>where
Idx: Into<ContiguousArenaIndex>,
Gets a mutable reference to the object identified by handle.
Sourcepub fn values_mut(&mut self) -> IterMut<'_, T> ⓘ
pub fn values_mut(&mut self) -> IterMut<'_, T> ⓘ
Gets mutable references to all the objects on this set.
Sourcepub fn iter<'a>(&'a self) -> impl Iterator<Item = (Idx, &'a T)> + 'awhere
Idx: From<ContiguousArenaIndex>,
pub fn iter<'a>(&'a self) -> impl Iterator<Item = (Idx, &'a T)> + 'awhere
Idx: From<ContiguousArenaIndex>,
Iter through all the objects as well as their handle.
Sourcepub fn as_mut_slice(&mut self) -> &mut [T]
pub fn as_mut_slice(&mut self) -> &mut [T]
Retrieves the set of objects as a mutable slice.
Sourcepub fn insert(&mut self, object: T) -> Idxwhere
Idx: From<ContiguousArenaIndex>,
pub fn insert(&mut self, object: T) -> Idxwhere
Idx: From<ContiguousArenaIndex>,
Insert an object into this set.
Sourcepub fn remove(&mut self, handle: Idx) -> Option<T>where
Idx: Into<ContiguousArenaIndex>,
pub fn remove(&mut self, handle: Idx) -> Option<T>where
Idx: Into<ContiguousArenaIndex>,
Remove an object from this set.